#if !defined(_LOG_H_)
#define _LOG_H_
/*
file:			log.h
author:		Allan Kelly
date:		10 August 1999
*/

// system includes ---------------------------
#include <string>
#include <strstream>

// project includes --------------------------
// <none>

// local includes ----------------------------
// <none>

// forward declarations ----------------------
// <none>

namespace Log
{
	// base class for log sinks
	class LogSink
	{
	public:
		explicit LogSink() {}
		virtual ~LogSink() = 0 {}

		// four types of message may be logged
		virtual void Debug(const std::string&) const = 0;
		virtual void Information(const std::string&) const = 0;
		virtual void Warning(const std::string&) const = 0;
		virtual void Error(const std::string&) const = 0;
	};

	// namespace adopts classes of type Sink to send messages to
	void AdoptSink(const std::string& name, LogSink* const);

	// remove a named sink from the destinations
	// returns NULL if no sink of given name
	LogSink* OrphanSink(const std::string& name);

	// syntatic sugar to allow multiple types of strings
	// classes are empty so the compiler should opimise them away
	void Debug(const std::string&);
	struct DebugMsg : public std::strstream	{ };

	void Information(const std::string& msg);
	struct InformationMsg : public std::strstream 	{ };

	void Warning(const std::string& msg);
	struct WarningMsg : public std::strstream 	{ };

	void Error(const std::string& msg);
	struct ErrorMsg : public std::strstream { };

	struct LogStream
	{ };

	LogStream& MsgOut();

	// now operators to simplify logging
	LogStream& operator<<(LogStream&, DebugMsg&);
	LogStream& operator<<(LogStream&, InformationMsg&);
	LogStream& operator<<(LogStream&, WarningMsg&);
	LogStream& operator<<(LogStream&, ErrorMsg&);
}

#endif
