/*	file	:	main.cpp
	purpose	:	demonstrator log namespace in action
	author	:	Allan Kelly
	date	:	10 August 1999
*/

// System includes ---------------------
#include <iostream>
#include <ctime>

// Project includes --------------------
#include <Log.h>
#include <StdError.h>
#include <FileError.h>
#include <BoxError.h>

// Local includes ----------------------
// <none>

int main(int, char*[])
{
	int r = 0;	// return value
	std::cout << "Welcome to log tester....." << std::endl;

	try
	{
		Log::InformationMsg msg;
		Log::Debug("Creating std error sink");
		Log::AdoptSink("Console", new Log::StdError());

		time_t t = time(NULL);
		tm *tt = gmtime(&t);
		msg << "Standard error has been adopted at " 
			<< tt->tm_hour << ":" << tt->tm_min << std::endl;

		Log::Debug("Creating file error sink");
		Log::AdoptSink("File", new Log::FileError("Log.out"));
		msg << "File error has been adopted" << std::endl;

		Log::Debug("Removing std error sink");
		Log::LogSink* s = Log::OrphanSink("Console");
		delete s;

		Log::Debug("Creating box error sink");
		Log::AdoptSink("Window", new Log::BoxError(NULL));
		msg << "Box error has been adopted" << std::endl;

		Log::MsgOut() << msg;
		Log::Warning("That's all folks!");
	}
	catch(...)
	{
		Log::Error("Something went wrong!");
	}

	Log::DebugMsg dmsg;
	dmsg << "Returning value " << r;
	Log::MsgOut() << dmsg;
	return r;
}

	